@@ -1,4 +1,5 @@
 import os
+import pip
 import sys
 import time
 import logging
@@ -47,6 +48,7 @@ class ErrorReporting(QDialog):
         WIDGET_MODULE = 'Widget Module'
         VERSION = 'Version'
         ENVIRONMENT = 'Environment'
+        INSTALLED_PACKAGES = 'Installed Packages'
         MACHINE_ID = 'Machine ID'
         WIDGET_SCHEME = 'Widget Scheme'
         STACK_TRACE = 'Stack Trace'
@@ -131,6 +133,8 @@ class ErrorReporting(QDialog):
 
         if QSettings().value('error-reporting/add-scheme', True, type=bool):
             data[F.WIDGET_SCHEME] = data['_' + F.WIDGET_SCHEME]
+        else:
+            data.pop(F.WIDGET_SCHEME, None)
         del data['_' + F.WIDGET_SCHEME]
 
         def _post_report(data):
@@ -183,6 +187,9 @@ class ErrorReporting(QDialog):
             widget = frame.tb_frame.f_locals['self'].__class__
             widget_module = '{}:{}'.format(widget.__module__, frame.tb_lineno)
 
+        packages = ', '.join(sorted("%s==%s" % (i.project_name, i.version)
+                                    for i in pip.get_installed_distributions()))
+
         # If this exact error was already reported in this session,
         # just warn about it
         if (err_module, widget_module) in cls._cache:
@@ -219,6 +226,7 @@ class ErrorReporting(QDialog):
         data[F.ENVIRONMENT] = 'Python {} on {} {} {} {}'.format(
             platform.python_version(), platform.system(), platform.release(),
             platform.version(), platform.machine())
+        data[F.INSTALLED_PACKAGES] = packages
         data[F.MACHINE_ID] = str(uuid.getnode())
         data[F.STACK_TRACE] = stacktrace
         if err_locals:
