@@ -692,6 +692,9 @@ class OWHeatMap(widget.OWWidget):
                 data_sample.download_data(2000, partial=True)
                 data = Table(data_sample)
 
+        if data is not None and not len(data):
+            data = None
+
         if data is not None and sp.issparse(data.X):
             try:
                 data = data.copy()
